@@ -12,11 +12,9 @@ case "${CCNAME}" in
 esac
 
 case "${GCC_VERS}" in
-	4.8.[456789])
-		;;
-	*)
-		exit 1
+	4.9.*)
+		exit 0
 		;;
 esac
 
-exit 0
+exit 1
