@@ -3,7 +3,7 @@
 GCC_VERS="$1"
 
 case "${GCC_VERS}" in
-	4.9.*)
+	4.9.[012])
 		exit 0
 		;;
 esac
